package com.qiaoba.common.database.entity;

import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serializable;
import java.util.Objects;

/**
 * 动态数据源实体
 *
 * @author ailanyin
 * @version 1.0
 * @since 2023-06-13 20:24:31
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
public class DynamicDataSource implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 数据源ID
     */
    private String datasourceId;

    /**
     * 主要数据源
     */
    private String isPrimary;

    /**
     * 数据库-url
     */
    private String url;

    /**
     * 数据库-username
     */
    private String username;

    /**
     * 数据库-password
     */
    private String password;

    /**
     * 数据库-驱动
     */
    private String driver;

    /**
     * 连接池-初始化大小
     */
    private Integer initialSize;

    /**
     * 连接池-最小空闲线程数
     */
    private Integer minIdle;

    /**
     * 连接池-最大连接池数量
     */
    private Integer maxActive;

    /**
     * 租户ID
     */
    private String tenantId;

    /**
     * 服务器SN
     */
    private String serverSn;


    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DynamicDataSource that = (DynamicDataSource) o;
        return url.equals(that.url) &&
                tenantId.equals(that.tenantId);
    }

    @Override
    public int hashCode() {
        return Objects.hash(url, tenantId);
    }

}
