package com.qiaoba.module.tenant.service;

import com.qiaoba.api.tenant.entity.SysTenantDatasource;
import com.qiaoba.api.tenant.entity.param.SysTenantDatasourceParam;
import com.qiaoba.common.database.entity.DynamicDataSource;

import java.util.List;

/**
 * 租户数据源 服务层
 *
 * @author ailanyin
 * @version 1.0
 * @since 2023/6/7 14:48
 */
public interface SysTenantDatasourceService {

    /**
     * 查询租户的主要数据源
     *
     * @param tenantId 租户ID
     * @return 数据源
     */
    SysTenantDatasource selectPrimary(String tenantId);

    /**
     * 查询租户的主要数据源
     *
     * @param tenantId  租户ID
     * @param allowNull 允许空
     * @return 数据源
     */
    SysTenantDatasource selectPrimary(String tenantId, boolean allowNull);

    /**
     * 通过IP查询
     *
     * @param tenantId tenantId
     * @param ip       ip
     * @return obj
     */
    SysTenantDatasource selectByIp(String tenantId, String ip);

    /**
     * 新增
     *
     * @param sysTenantDatasource sysTenantDatasource
     * @return 结果
     */
    int insert(SysTenantDatasource sysTenantDatasource);

    /**
     * 修改
     *
     * @param sysTenantDatasource sysTenantDatasource
     * @return 结果
     */
    int updateById(SysTenantDatasource sysTenantDatasource);

    /**
     * 更新状态
     *
     * @param sysTenantDatasource sysTenantDatasource
     * @return 结果
     */
    int updateStatus(SysTenantDatasource sysTenantDatasource);

    /**
     * 批量删除
     *
     * @param ids ids
     * @return 结果
     */
    int deleteByIds(List<String> ids);

    /**
     * 查询租户的所有数据源
     *
     * @param tenantId tenantId
     * @return list
     */
    List<SysTenantDatasource> selectList(String tenantId);

    /**
     * 查询租户数据源
     *
     * @param param 条件
     * @return list
     */
    List<SysTenantDatasource> selectList(SysTenantDatasourceParam param);

    /**
     * 将租户下的除datasourceId之外的其他数据源设置为备用
     *
     * @param tenantId  tenantId
     * @param excludeId 排除Id
     */
    void setBackupDatasourceExcludeId(String tenantId, String excludeId);

    /**
     * 切换为主数据源
     *
     * @param tenantId     租户ID
     * @param datasourceId 数据源ID
     * @return 结果
     */
    int switchPrimary(String tenantId, String datasourceId);

    /**
     * datasource2DynamicDataSource
     *
     * @param datasource 数据源
     * @return 数据源
     */
    DynamicDataSource transform(SysTenantDatasource datasource);
}
